==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/machinelearningservices/kotlin/inputs/ComputeInstanceArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.machinelearningservices.kotlin.inputs

import com.pulumi.azurenative.machinelearningservices.inputs.ComputeInstanceArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * An Azure Machine Learning compute instance.
 * @property computeLocation Location for the underlying compute
 * @property computeType The type of compute
 * Expected value is 'ComputeInstance'.
 * @property description The description of the Machine Learning compute.
 * @property disableLocalAuth Opt-out of local authentication and ensure customers can use only MSI and AAD exclusively for authentication.
 * @property properties Properties of ComputeInstance
 * @property resourceId ARM resource id of the underlying compute
 */
public data class ComputeInstanceArgs(
    public val computeLocation: Output<String>? = null,
    public val computeType: Output<String>,
    public val description: Output<String>? = null,
    public val disableLocalAuth: Output<Boolean>? = null,
    public val properties: Output<ComputeInstancePropertiesArgs>? = null,
    public val resourceId: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.machinelearningservices.inputs.ComputeInstanceArgs> {
    override fun toJava(): com.pulumi.azurenative.machinelearningservices.inputs.ComputeInstanceArgs =
        com.pulumi.azurenative.machinelearningservices.inputs.ComputeInstanceArgs.builder()
            .computeLocation(computeLocation?.applyValue({ args0 -> args0 }))
            .computeType(computeType.applyValue({ args0 -> args0 }))
            .description(description?.applyValue({ args0 -> args0 }))
            .disableLocalAuth(disableLocalAuth?.applyValue({ args0 -> args0 }))
            .properties(properties?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .resourceId(resourceId?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ComputeInstanceArgs].
 */
@PulumiTagMarker
public class ComputeInstanceArgsBuilder internal constructor() {
    private var computeLocation: Output<String>? = null

    private var computeType: Output<String>? = null

    private var description: Output<String>? = null

    private var disableLocalAuth: Output<Boolean>? = null

    private var properties: Output<ComputeInstancePropertiesArgs>? = null

    private var resourceId: Output<String>? = null

    /**
     * @param value Location for the underlying compute
     */
    @JvmName("jsqktkqenqbvoedo")
    public suspend fun computeLocation(`value`: Output<String>) {
        this.computeLocation = value
    }

    /**
     * @param value The type of compute
     * Expected value is 'ComputeInstance'.
     */
    @JvmName("enytfgfcotihpvjn")
    public suspend fun computeType(`value`: Output<String>) {
        this.computeType = value
    }

    /**
     * @param value The description of the Machine Learning compute.
     */
    @JvmName("jyfpsdnaeslqtuxe")
    public suspend fun description(`value`: Output<String>) {
        this.description = value
    }

    /**
     * @param value Opt-out of local authentication and ensure customers can use only MSI and AAD exclusively for authentication.
     */
    @JvmName("iybarjasudtqdobq")
    public suspend fun disableLocalAuth(`value`: Output<Boolean>) {
        this.disableLocalAuth = value
    }

    /**
     * @param value Properties of ComputeInstance
     */
    @JvmName("yfmjgtlnxcsysify")
    public suspend fun properties(`value`: Output<ComputeInstancePropertiesArgs>) {
        this.properties = value
    }

    /**
     * @param value ARM resource id of the underlying compute
     */
    @JvmName("eygxnraxkucrlpry")
    public suspend fun resourceId(`value`: Output<String>) {
        this.resourceId = value
    }

    /**
     * @param value Location for the underlying compute
     */
    @JvmName("fbsboxptmlyfcrhy")
    public suspend fun computeLocation(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.computeLocation = mapped
    }

    /**
     * @param value The type of compute
     * Expected value is 'ComputeInstance'.
     */
    @JvmName("jyqchkhlunhhfkvk")
    public suspend fun computeType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.computeType = mapped
    }

    /**
     * @param value The description of the Machine Learning compute.
     */
    @JvmName("ekwdbqnxoretqpdm")
    public suspend fun description(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.description = mapped
    }

    /**
     * @param value Opt-out of local authentication and ensure customers can use only MSI and AAD exclusively for authentication.
     */
    @JvmName("fpvnkvnwrjbtkgkr")
    public suspend fun disableLocalAuth(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.disableLocalAuth = mapped
    }

    /**
     * @param value Properties of ComputeInstance
     */
    @JvmName("enuplqgydiyuilps")
    public suspend fun properties(`value`: ComputeInstancePropertiesArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.properties = mapped
    }

    /**
     * @param argument Properties of ComputeInstance
     */
    @JvmName("owkoxlmqmklwxvtk")
    public suspend fun properties(argument: suspend ComputeInstancePropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = ComputeInstancePropertiesArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.properties = mapped
    }

    /**
     * @param value ARM resource id of the underlying compute
     */
    @JvmName("nvqswfghkbuyrwir")
    public suspend fun resourceId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceId = mapped
    }

    internal fun build(): ComputeInstanceArgs = ComputeInstanceArgs(
        computeLocation = computeLocation,
        computeType = computeType ?: throw PulumiNullFieldException("computeType"),
        description = description,
        disableLocalAuth = disableLocalAuth,
        properties = properties,
        resourceId = resourceId,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/machinelearningservices/kotlin/inputs/ComputeInstanceArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.machinelearningservices.kotlin.inputs

import com.pulumi.azurenative.machinelearningservices.inputs.ComputeInstanceArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * An Azure Machine Learning compute instance.
 * @property computeLocation Location for the underlying compute
 * @property computeType The type of compute
 * Expected value is 'ComputeInstance'.
 * @property description The description of the Machine Learning compute.
 * @property disableLocalAuth Opt-out of local authentication and ensure customers can use only MSI and AAD exclusively for authentication.
 * @property properties Properties of ComputeInstance
 * @property resourceId ARM resource id of the underlying compute
 */
public data class ComputeInstanceArgs(
    public val computeLocation: Output<String>? = null,
    public val computeType: Output<String>,
    public val description: Output<String>? = null,
    public val disableLocalAuth: Output<Boolean>? = null,
    public val properties: Output<ComputeInstancePropertiesArgs>? = null,
    public val resourceId: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.machinelearningservices.inputs.ComputeInstanceArgs> {
    override fun toJava(): com.pulumi.azurenative.machinelearningservices.inputs.ComputeInstanceArgs =
        com.pulumi.azurenative.machinelearningservices.inputs.ComputeInstanceArgs.builder()
            .computeLocation(computeLocation?.applyValue({ args0 -> args0 }))
            .computeType(computeType.applyValue({ args0 -> args0 }))
            .description(description?.applyValue({ args0 -> args0 }))
            .disableLocalAuth(disableLocalAuth?.applyValue({ args0 -> args0 }))
            .properties(properties?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .resourceId(resourceId?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ComputeInstanceArgs].
 */
@PulumiTagMarker
public class ComputeInstanceArgsBuilder internal constructor() {
    private var computeLocation: Output<String>? = null

    private var computeType: Output<String>? = null

    private var description: Output<String>? = null

    private var disableLocalAuth: Output<Boolean>? = null

    private var properties: Output<ComputeInstancePropertiesArgs>? = null

    private var resourceId: Output<String>? = null

    /**
     * @param value Location for the underlying compute
     */
    @JvmName("flwoegvvsdsysesj")
    public suspend fun computeLocation(`value`: Output<String>) {
        this.computeLocation = value
    }

    /**
     * @param value The type of compute
     * Expected value is 'ComputeInstance'.
     */
    @JvmName("hgcweqbawxjngeyg")
    public suspend fun computeType(`value`: Output<String>) {
        this.computeType = value
    }

    /**
     * @param value The description of the Machine Learning compute.
     */
    @JvmName("djeypnrvujsqlxeg")
    public suspend fun description(`value`: Output<String>) {
        this.description = value
    }

    /**
     * @param value Opt-out of local authentication and ensure customers can use only MSI and AAD exclusively for authentication.
     */
    @JvmName("qxpiowupdgiikaef")
    public suspend fun disableLocalAuth(`value`: Output<Boolean>) {
        this.disableLocalAuth = value
    }

    /**
     * @param value Properties of ComputeInstance
     */
    @JvmName("dwigjtrtqqwgovck")
    public suspend fun properties(`value`: Output<ComputeInstancePropertiesArgs>) {
        this.properties = value
    }

    /**
     * @param value ARM resource id of the underlying compute
     */
    @JvmName("rvfilvwiswvjvfdy")
    public suspend fun resourceId(`value`: Output<String>) {
        this.resourceId = value
    }

    /**
     * @param value Location for the underlying compute
     */
    @JvmName("baujxjhkgigsqygi")
    public suspend fun computeLocation(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.computeLocation = mapped
    }

    /**
     * @param value The type of compute
     * Expected value is 'ComputeInstance'.
     */
    @JvmName("qcwkonytellkekjq")
    public suspend fun computeType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.computeType = mapped
    }

    /**
     * @param value The description of the Machine Learning compute.
     */
    @JvmName("vymwvmbxgqvtxxqg")
    public suspend fun description(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.description = mapped
    }

    /**
     * @param value Opt-out of local authentication and ensure customers can use only MSI and AAD exclusively for authentication.
     */
    @JvmName("rgmcwqvkcoxdnjml")
    public suspend fun disableLocalAuth(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.disableLocalAuth = mapped
    }

    /**
     * @param value Properties of ComputeInstance
     */
    @JvmName("lecxbykfcygtnjlh")
    public suspend fun properties(`value`: ComputeInstancePropertiesArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.properties = mapped
    }

    /**
     * @param argument Properties of ComputeInstance
     */
    @JvmName("tsrbvvdspcctxvdh")
    public suspend fun properties(argument: suspend ComputeInstancePropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = ComputeInstancePropertiesArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.properties = mapped
    }

    /**
     * @param value ARM resource id of the underlying compute
     */
    @JvmName("dunhwxudglwhonrj")
    public suspend fun resourceId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceId = mapped
    }

    internal fun build(): ComputeInstanceArgs = ComputeInstanceArgs(
        computeLocation = computeLocation,
        computeType = computeType ?: throw PulumiNullFieldException("computeType"),
        description = description,
        disableLocalAuth = disableLocalAuth,
        properties = properties,
        resourceId = resourceId,
    )
}
